#
# spec file for package python3-django-haystack
#
# Copyright (c) 2017 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.
#
# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           python3-django-haystack
Version:        2.6.0
Release:        1.17
Url:            http://haystacksearch.org/
Summary:        Pluggable search for Django
License:        BSD-2-Clause
Group:          Development/Languages/Python
Source:         https://files.pythonhosted.org/packages/source/d/django-haystack/django-haystack-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python3-devel
BuildRequires:  python3-django
BuildRequires:  python3-Sphinx
BuildRequires:  python3-setuptools
BuildRequires:  python3-setuptools_scm
Requires:       python3-django
BuildArch:      noarch

%description
Haystack provides modular search for Django. It features a unified, familiar
API that allows you to plug in different search backends (such as Solr,
Whoosh, Xapian, etc.) without having to modify your code.

%prep
%setup -q -n django-haystack-%{version}

%build
python3 setup.py build
cd docs
make html

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
# remove .buildinfo files
rm docs/_build/html/.buildinfo

%files
%defattr(-,root,root,-)
%doc AUTHORS LICENSE README.rst docs/_build/html
%{python3_sitelib}/*

%changelog
* Tue Jan 10 2017 arun@gmx.de
- specfile:
  * update copyright year
  * require python3-setuptools_scm
- update to version 2.6.0:
  * Merge #1460: backend support for Elasticsearch 2.x. [Chris Adams]
  * Docs: update Elasticsearch support status. [Chris Adams]
  * Tests: avoid unrelated failures when elasticsearch is not
    installed.  [Chris Adams]
  * Tests: friendlier log message for ES version checks. [Chris Adams]
  * Tests: update ES version detection in settings. [Chris Adams]
  * Tests: update ES1 client version check message. [Chris Adams]
  * Update travis script with ES documentation. [Chris Adams]
  * Fixed More Like This test with deferred query on Elasticsearch
    2.x.  [Bruno Marques]
  * Fixed expected query behaviour on ES2.x test. [Bruno Marques]
  * Install elasticsearch2.0 via apt. [joaojunior]
  * Remove typo. [joaojunior]
  * Remove services elasticsearch. [joaojunior]
  * Fix typo. [joaojunior]
  * Sudo=true in .travis.yml to install elasticsearch from apt-get.
    [joaojunior]
  * Fix .travis. [joaojunior]
  * Add logging in __init__ tests elasticsearch. [joaojunior]
  * Get changes from Master to resolve conflicts. [joaojunior]
  * Install elasticsearch1.7 via apt. [joaojunior]
  * Update Files to run tests in Elasticsearch2.x. [joaojunior]
  * Refactoring the code in pull request #1336 . This pull request is
    to permit use ElasticSearch 2.X. [joaojunior]
  * Improved custom object identifier test. [Chris Adams]
  * Update management backend documentation for `--using` [flinkflonk]
  * Fix filtered "more like this" queries (#1459) [David Cook]
  * ReStructuredText link format fixes. (#1458) [John Heasly]
  * Add note to Backend Support docs about lack of ES 5.X
    support. (#1457) [John Heasly]
  * Replace deprecated Point.get_coords() calls. [Chris Adams]
  * Use setuptools_scm to manage package version numbers. [Chris
    Adams]
* Mon Dec 12 2016 arun@gmx.de
- update to version 2.5.1:
  (no changelog available)
* Wed Jul 13 2016 arun@gmx.de
- specfile:
  * update copyright year
- update to version 2.5.0:
  (no changelog available)
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Sat Oct 31 2015 arun@gmx.de
- update to version 2.4.1:
  * Minimal changes to the example project to allow test use
  * Rename 'page_obj' with 'page' in the tutorial, section Search
    Template as there is no 'page_obj' in the controller and this
    results giving 'No results found' in the search.
  * Style cleanup
  * Update backend logging style
  * Avoid unsafe default value on backend clear() methods
  * fix #1253
  * Tests: update Solr launcher for changed mirror format
  * Bump doc version numbers - closes #1105
  * Update tutorial.rst
  * Use a faster implementation of this horrible cache. In my tests it
    runs much faster and uses far less memory.
  * Rename elasticsearch-py to elasticsearch in docs
  * Allow failures on Python 2.6
  * Travis: stop testing unsupported versions of Django on Python 2.6
  * Use Travis’ matrix support rather than tox
  * Tests: update the test version of Solr in use
  * Corrected exception wording
  * Updated documentation, facet_fields attribute
  * Added facet_fields attribute
  * Bugfixes
* Tue Jun 16 2015 arun@gmx.de
- specfile:
  * update copyright year
  * create doc using Sphinx
- update to version 2.4.0:
  * Django 1.8 is supported (see #1175, #1165, #1162, #1137)
  * AppConfig is fully supported for Django 1.7+ (#1152)
  * During indexing, the process method can raise
    haystack.exceptions.SkipDocument to skip individual records which
    are not be easily excluded using index_queryset
  * ElasticSearch: distance queries and compatibility changes with the
    elasticsearch client library have been fixed
  * The new generic_views module uses the standard Django classes to
    replace the older views module
  * SearchQuerySet’s narrow() method now accepts SQ instances
  * Deprecations
    + Python 2.6 is no longer supported
    + Django 1.5 is no longer supported
    + The old class-based views which predated Django's CBVs have been
    deprecated in favor of the new generic_views module using the
    standard Django classes. See #1130.
    + Several undocumented spatial search methods have been removed:
    SearchQuerySet.order_by_distance(), and the add_spatial() and
    add_order_by_distance() methods on SolrSearchQuery or
    ElasticsearchSearchQuery. The standard order_by('distance') and
    other spatial query methods in the documentation are unaffected.
    + The old haystack.utils.method_decorator has been removed since
    all supported versions of Django have
    django.utils.decorator.method_decorator.
* Wed Dec  3 2014 arun@gmx.de
- specfile: updated copyright year
- update to version 2.3.1
  * Allow apps without models.py on Django <1.7
  * Tolerate non-importable apps like django-debug-toolbar
- change from version 2.3.0:
  * Refactor get_model_ct to handle Django 1.7, add tuple version
  * Consolidate model meta references to use get_model_ct (see #981)
  * Haystack admin: refactor to use get_model_ct_tuple
  * Refactor simple_backend to use get_model_ct_tuple
  * Use get_model_ct_tuple to generate template name
  * Tests: add MIDDLEWARE_CLASSES for Django 1.7
  * Unpin elasticsearch library version for testing
  * Tests: Whoosh test overhaul
  * Add Django 1.7 warning to Sphinx docs as well
  * Django 1.7: ensure that the app registry is ready before tests are loaded
  * Mark expected failures for Django 1.7 (see #1069)
  * Update tox Django version pins
  * Django 1.7 compatibility for model loading
  * Start the process of updating for v2.3 release
  * Django 1.7 support for app discovery
  * Remove Django version pin from install_requires
  * App Loading: don’t suppress app-registry related exceptions
  * app loading: use ImproperlyConfigured for bogus app names
  * Fix app loading call signature
  * Travis: Enable IRC notifications
- changes from version 2.2.1:
  * Fixed typo in example
  * Update Xapian install
  * Fixed the installing search engine doc URL
  * Link to 'signal processors'
  * Docs: fix signal processors link in searchindex_api
  * Add PyPy targets to Tox & Travis
  * Update example for Faceting to reference page.object_list
  * Fallback to pwd if realpath is not available
  * Travis, Tox: add Django 1.7 targets
  * Update Travis & Tox config
  * Tests: don't suppress Solr stderr logging
  * Mark 2.2.X as incompatible with Django 1.7
- changes from version 2.2.0:
  * #951: Complete refactoring of the test suite (thanks @HonzaKral!)
    which makes it easier to use and faster
  * #407: Fixed doc: query is context variable and not in request
  * #413: Fixed warning when models() is called with an unregistered model
  * #775: Avoid unnecessary db query on index update
  * #795: Improve error message for duplicate index classes
  * #840, #807: Incorrect Clean input behaviour for Elasticsearch engine
  * 30afd1f Fixed a missed raw_input call on Python 3
  * #847: Fixed an update_index bug when using multiple connections
  * 1cfb6c6 Pass using to index_queryset for update
  * 4956486 Fixed simple backend for Django 1.6, _fields was removed.
  * 3ef5644 Fixed autocomplete() method with spaces in query
  * #575 & #838: fixed an incompatibility with Whoosh 2.5>
  * ab145f3 Fixed ValueError exception when SILENTLY_FAIL=True
  * #886: Use Filtered queries more efficiently for elasticsearch
  * #899: Use HTML5
  * #885: Use elasticsearch-py instead of pyelasticsearch
  * #775, #718: Fix bounding box calculation for spatial queries
  * 6d3daa6 Whoosh: allow multiple order_by() fields
  * f7d4fad Simplified mappings for ElasticSearch fields
  * #888: run() kwargs are passed directly to search backend, fixing
    values_list and making subclassing easier (Solr, ElasticSearch)
  * Solr backend: correct usage of pysolr delete (#943)
  * Small docs fix for spatial search example code (#946)
  * Fix logging call in SQS post_process_results (see #648)
  * ElasticSearch: avoid KeyError for empty spelling suggestions (thanks @skoczen)
  * RelatedSearchQuerySet: move class globals to instance properties,
    avoiding conflicts with multiple instances
  * Update ElasticSearch for 1.0+ syntax 0043fac
* Wed Oct 23 2013 toddrme2178@gmail.com
- Add BuildRequires:  python3-django
* Fri Sep 27 2013 p.drouand@gmail.com
- Initial python3 support
* Fri Sep 27 2013 p.drouand@gmail.com
- Update to version 2.1.0
  + No changelog available
- Use download url as source url
- Add AUTHORS LICENSE README and html doc in package documentation
* Sat Apr  7 2012 alexandre@exatati.com.br
- Update to 1.2.7:
  - Sorry, no changelog.
* Fri Dec  9 2011 alexandre@exatati.com.br
- Updaet to 1.2.6:
  - Sorry, no changelog.
* Wed Sep 14 2011 alexandre@exatati.com.br
- Update to 1.2.5:
  - Sorry, no changelog.
* Sat May 28 2011 alexandre@exatati.com.br
- Update to 1.2.4:
  - Sorry, no changelog.
* Fri May 20 2011 alexandre@exatati.com.br
- Update to 1.2.3:
  - Sorry, no changelog.
* Sat May 14 2011 alexandre@exatati.com.br
- Update to 1.2.1:
  - Sorry, no changelog.
* Tue May  3 2011 alexandre@exatati.com.br
- Update to 1.2.0:
  - Sorry, no changelog.
- Regenerate spec file with py2pack.
* Tue Nov 23 2010 alexandre@exatati.com.br
- Update to 1.1.0.
* Wed Oct 27 2010 alexandre@exatati.com.br
- Update to 1.0.2-final;
- Bzip2 source file;
- Spec file cleaned with spec-cleaner.
* Mon Nov 30 2009 alexandre@exatati.com.br
- Update to 1.0.1-final.
* Mon Nov 30 2009 alexandre@exatati.com.br
- Update to 1.0.0-final.
* Tue Nov 24 2009 alexandre@exatati.com.br
- Initial package (1.0.0-rc1).
